From e8a2f4d6344a87c09f2e990dd8708bc35d315295 Mon Sep 17 00:00:00 2001
From: Hugo Beauzee-Luyssen <chouquette@otterz.localdomain>
Date: Mon, 18 Jan 2010 02:18:16 +0100
Subject: [PATCH] Send an event when snapshot capture failed.

---
 src/control/media_player.c   |    5 ++++-
 src/video_output/vout_intf.c |    9 ++++++---
 2 files changed, 10 insertions(+), 4 deletions(-)

diff --git a/src/control/media_player.c b/src/control/media_player.c
index 3bd4fa6..d097688 100644
--- a/src/control/media_player.c
+++ b/src/control/media_player.c
@@ -309,7 +309,10 @@ static int snapshot_was_taken(vlc_object_t *p_this, char const *psz_cmd,
     libvlc_media_player_t *mp = p_data;
     libvlc_event_t event;
     event.type = libvlc_MediaPlayerSnapshotTaken;
-    event.u.media_player_snapshot_taken.psz_filename = newval.psz_string;
+    if ( !strcmp( "(null)", newval.psz_string ))
+        event.u.media_player_snapshot_taken.psz_filename = NULL;
+    else
+        event.u.media_player_snapshot_taken.psz_filename = newval.psz_string;
     libvlc_event_send(mp->p_event_manager, &event);
 
     return VLC_SUCCESS;
diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 3336481..ca06cd5 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -477,7 +477,7 @@ static void VoutSaveSnapshot( vout_thread_t *p_vout )
     {
         p_picture = NULL;
         p_image = NULL;
-        goto exit;
+        goto failure;
     }
 
     if( !psz_path )
@@ -486,7 +486,7 @@ static void VoutSaveSnapshot( vout_thread_t *p_vout )
         if( !psz_path )
         {
             msg_Err( p_vout, "no path specified for snapshots" );
-            goto exit;
+            goto failure;
         }
     }
 
@@ -502,7 +502,7 @@ static void VoutSaveSnapshot( vout_thread_t *p_vout )
     int  i_sequence;
     if (vout_snapshot_SaveImage( &psz_filename, &i_sequence,
                                  p_image, VLC_OBJECT(p_vout), &cfg ) )
-        goto exit;
+        goto failure;
     if( cfg.is_sequential )
         var_SetInteger( p_vout, "snapshot-num", i_sequence + 1 );
 
@@ -512,7 +512,10 @@ static void VoutSaveSnapshot( vout_thread_t *p_vout )
     var_SetString( p_vout->p_libvlc, "snapshot-file", psz_filename );
 
     free( psz_filename );
+    goto exit;
 
+failure:
+    var_SetString( p_vout->p_libvlc, "snapshot-file", "(null)" );
 exit:
     if( p_image )
         block_Release( p_image );
-- 
1.6.6

